// Importing the required modules for the task.
import { getData } from './getdata';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Declaring constants that takes data from html file
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Creating a pie chart
const render = (data,total) => {
  const pieData = pie().value(d=>d.NETWORTH)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range([
      "#FFD700",
      "#018670",
      "#B22222",
      "#8dc63f",
      "#f58026",
      "#4b4b4b",
      "#9acbc2",
      "#00b5cc",
      "#014140",
      "#d9d5d5",
      "#9400D3"
    ]);
  
 //Partitions in pie chart 
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.NETWORTH));
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.NETWORTH));
  
  //Naming legends
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.NAME);
  
  //Displaying the values
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.NETWORTH))+'BILLION');
}

//Main pie chart implementation
const run = async () => {
  let data = await getData()
  let total = 0
  data.forEach(d=>{
    d.NETWORTH = +d.NETWORTH;
    total += d.NETWORTH
  });
  console.log(data)
	render(data,total);
};
run();